/*
 * [ZDStatus.java]
 *
 * Summary: enumeration of possible statuses a zip file can have.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 * 10.2 2009-04-03 tidy up code to check presence of necessary files to make it more WORA.
 */
package com.mindprod.replicatorsender;

import java.io.Serializable;

/**
 * enumeration of possible statuses a zip file can have.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 10.2 2009-04-03 tidy up code to check presence of necessary files to make it more WORA.
 * @since 2002
 */
public enum ZDStatus implements Serializable
    {
        /**
         * A brand new zip that has not yet been created and filled with element files.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) A_UNCREATED,
        /**
         * The zip has been created and filled with element files. It is part of the official archive set.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) B_CREATED,
        /**
         * All files in this zip have been reassigned to other zips. This is one step before RETIRED.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) C_DECOMMISSIONED,
        /**
         * This zip file is obsolete, either because all its elements were updated and now live in other files, or
         * because it was consolidated with another zip to reduce deadwood. It is kept around because the website may
         * still refer to it for a short while.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) D_RETIRED,
        /**
         * The zip file has been reduced to a zero byte file. This is to ensure deleted files take no room on the
         * website even if the upload software is not smart enough to delete them.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) E_EMACIATED,
        /**
         * This jar has been deleted. Soon all record of its existence will be expunged.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) F_DELETED;

    /**
     * Layout version number.
     */
    public static final long serialVersionUID = 300L;
    }
